#include "TemplateBuilder.hh"
#include "fastjet/PseudoJet.hh"
#include "fastjet/ClusterSequence.hh"
#include <iomanip> // for std::setw

TemplateModel to_enum(int n)
{
  switch( n )
  {
    case 0 :  return TOP;
    case 1 : return HIGGS2;
    case 2 : return HIGGS3;
    default: return HIGGS2; //Make 2-body Higgs template default
  }
}


int main(int argc, char* argv[]) {
  
  if (argc !=8) {
    std::cout << "Usage:  "<< argv[0] << " <template.dat> R Mass pT nEta nPt model(0=TOP, 1=HIGGS2, 2=HIGGS3)" << std::endl;
    return 1;
  }
   /// Set Run Parameters 
  double R = atof(argv[2]); // anti-kt parameter
  double Mass = atof(argv[3]);
  double pT = atof(argv[4]);
  double px = pT, py = 0, pz = 0.;
  double ee = sqrt (px * px + py * py + pz * pz + Mass * Mass); 			
  fastjet::PseudoJet axis(px,py,pz,ee);	  
  
  double etaMax = R;
  double phiMax = R;
  double minPt = 10.; 
  int nEta = atoi(argv[5]);
  int nPhi = nEta;
  int nPt = atoi(argv[6]); 
  TemplateModel mode = to_enum(atoi(argv[7]));
  
  std::ofstream oFile(argv[1]);
  
  TemplateBuilder(oFile, axis, etaMax, phiMax, minPt, nEta, nPhi, nPt, R, mode);

 
  return 0;
}

